# This Week in Glean (TWiG)

“This Week in Glean” is a series of blog posts that the Glean Team at Mozilla is using to try to communicate better about our work.
They could be release notes, documentation, hopes, dreams, or whatever: so long as it is inspired by Glean.

## Blog posts

* 2019-10-17: [Glean on Desktop (Project FOG)](https://chuttenblog.wordpress.com/2019/10/17/this-week-in-glean-glean-on-desktop-project-fog/)
* 2019-10-24: [A Release](https://fnordig.de/2019/10/24/this-week-in-glean/)
* 2019-11-01: [A detective story](http://droettboom.com/blog/2019/11/01/this-week-in-glean-november-1-2019/)
* 2019-11-08: [Instrumenting Android Crashes with Glean](https://blogoftravis.wordpress.com/2019/11/08/this-week-in-glean-2019-11-08/)
* 2019-11-19: [GeckoView + Glean = Fenix performance metrics](https://www.a2p.it/wordpress/tech-stuff/mozilla/geckoview-glean-fenix-performance-metrics/)
* 2019-11-21: [What is the Glean logo about?](https://dianaciufo.wordpress.com/2019/10/11/glean-graphic-identity-for-mozilla-firefox/)
* 2019-11-22: [Glean in Private](https://chuttenblog.wordpress.com/2019/11/22/this-week-in-glean-glean-in-private/)
* 2019-11-29: [Differences](https://fnordig.de/2019/11/29/this-week-in-glean/)
* 2019-12-06: [Migrations](https://brizental.github.io/2019/12/06/this-week-in-glean-migrations.html)
* 2020-01-10: [Glossary](https://brizental.github.io/2020/01/10/this-week-in-glean-glossary.html)
* 2020-02-03: [Cargo features - an investigation](https://fnordig.de/2020/02/03/this-week-in-glean/)
* 2020-02-14: [Extending Glean: build re-usable types for new use-cases](https://www.a2p.it/wordpress/tech-stuff/mozilla/extending-glean-build-re-usable-types-for-new-use-cases/)
* 2020-02-21: [A Distributed Team Echoes Distributed Workflow](https://chuttenblog.wordpress.com/2020/02/21/this-week-in-glean-a-distributed-team-echoes-distributed-workflow/)
* 2020-02-28: [mozregression telemetry (part 1)](https://wlach.github.io/blog/2020/02/this-week-in-glean-special-guest-post-mozregression-telemetry-part-1/)
* 2020-03-09: [Metric lifetimes](https://blog.mozilla.org/data/2020/03/09/this-week-in-glean-metric-lifetimes/)
* 2020-03-13: [Adding support for GLAM on Glean](https://blog.mozilla.org/data/2020/03/13/this-week-in-glean-adding-support-for-glam-on-glean/)
* 2020-03-25: [Comparing Apples to Oranges](https://blog.mozilla.org/data/2020/03/25/this-week-in-glean-comparing-apples-to-oranges/)
* 2020-04-15: [How Much Does That Data Cost](https://chuttenblog.wordpress.com/2020/04/15/this-week-in-glean-how-much-does-that-data-cost/)
* 2020-04-27: [Glean for Python on Windows](https://blog.mozilla.org/data/2020/04/27/this-week-in-glean-glean-for-python-on-windows/)
* 2020-05-04: [Bytes in Memory (on Android)](https://fnordig.de/2020/05/04/this-week-in-glean/)
* 2020-05-08: [mozregression telemetry (part 2)](https://wlach.github.io/blog/2020/05/this-week-in-glean-mozregression-telemetry-part-2/)
* 2020-05-26: [How does the Glean SDK send gzipped pings](https://blog.mozilla.org/data/2020/05/26/how-does-the-glean-sdk-send-gzipped-pings/)
* 2020-06-03: [The Glean SDK and iOS Application Extensions, or a Tale of Two Sandboxes](https://blog.mozilla.org/data/2020/06/03/this-week-in-glean-the-glean-sdk-and-ios-application-extensions-or-a-tale-of-two-sandboxes/)
* 2020-06-12: [Project FOG Update, end of H12020](https://blog.mozilla.org/data/2020/06/12/this-week-in-glean-project-fog-update-end-of-h12020/)
* 2020-07-16: [Mozilla Telemetry in 2020: From “Just Firefox” to a “Galaxy of Data”](https://blog.mozilla.org/data/2020/07/16/mozilla-telemetry-in-2020-from-just-firefox-to-a-galaxy-of-data/)
* 2020-07-24: [Automated end-to-end tests for Glean](https://blog.mozilla.org/data/2020/07/24/this-week-in-glean-automated-end-to-end-tests-for-glean/)
* 2020-08-06: [Experimental integration Glean with Unity applications](https://blog.mozilla.org/data/2020/08/06/experimental-integration-glean-with-unity-applications/)
* 2020-09-01: [Leveraging Rust to build cross-platform mobile libraries](https://blog.mozilla.org/data/2020/09/01/twig-leveraging-rust/)
* 2020-09-25: [glean-core to Wasm experiment](https://blog.mozilla.org/data/2020/09/25/this-week-in-glean-glean-core-to-wasm-experiment/)
* 2020-10-06: [FOG Progress report](https://blog.mozilla.org/data/2020/10/06/this-week-in-glean-fog-progress-report/)
* 2020-10-21: [Cross-Platform Language Binding Generation with Rust and “uniffi”](https://blog.mozilla.org/data/2020/10/21/this-week-in-glean-cross-platform-language-binding-generation-with-rust-and-uniffi/)
* 2020-11-02: [Glean.js](https://blog.mozilla.org/data/2020/11/02/this-week-in-glean-glean-js/)
* 2020-11-19: [Fantastic Facts and Where To Find Them](https://blog.mozilla.org/data/2020/11/19/this-week-in-glean-fantastic-facts-and-where-to-find-them/)
* 2020-12-01: [Glean is Frictionless Data Collection](https://blog.mozilla.org/data/2020/12/01/this-week-in-glean-glean-is-frictionless-data-collection/)
* 2020-12-18: [Glean in 2021](https://fnordig.de/2020/12/18/glean-in-2021/)
* 2021-01-15: [Proposals for Asynchronous Design](https://blog.mozilla.org/data/2021/01/15/this-week-in-glean-proposals-for-asynchronous-design/)
* 2021-01-28: [The Glean Dictionary](https://blog.mozilla.org/data/2021/01/27/this-week-in-glean-the-glean-dictionary/)
* 2021-02-24: [Boring Monitoring](https://blog.mozilla.org/data/2021/02/24/this-week-in-glean-boring-monitoring/)
* 2021-03-16: [Reducing Release Friction](https://blog.mozilla.org/data/2021/03/16/this-week-in-glean-reducing-release-friction/)
* 2021-04-07: [Publishing Glean.js or “How I configured an npm package that has multiple entry points”](https://blog.mozilla.org/data/2021/04/07/this-week-in-glean-publishing-glean-js/)
* 2021-04-16: [rustc, iOS and an M1](https://blog.mozilla.org/data/2021/04/16/this-week-in-glean-rustc-ios-and-an-m1/)
* 2021-05-03: [Glean Dictionary updates](https://blog.mozilla.org/data/2021/06/02/this-week-in-glean-glean-dictionary-updates/)
